# *
# *	Copyright (c) 2000 Alberto Reggiori / <alberto.reggiori@jrc.it>
# *	ISIS/RIT, Joint Research Center Ispra (I)
# *
# * NOTICE
# *
# * This product is distributed under a BSD/ASF like license as described in the 'LICENSE'
# * file you should have received together with this source code. If you did not get a
# * a copy of such a license agreement you can pick up one at:
# *
# *     http://xml.jrc.it/RDFStore/LICENSE
# *
# *
package RDF::NodeFactory;
{
use RDF::Literal;
use RDF::Resource;
use RDF::Statement;

use Carp;

sub new {
    bless {}, shift;
};

sub createResource {
	return new RDF::Resource();
};

sub createLiteral {
	return new RDF::Literal();
};

sub createStatement {
	croak "Subject ".$_[1]." is not instance of RDF::Resource"
		unless( (not(defined $_[1])) ||
			($_[1]->isa('RDF::Resource')) );
	croak "Predicate ".$_[2]." is not instance of RDF::Resource"
		unless( (not(defined $_[2])) ||
			($_[2]->isa('RDF::Resource')) );
	croak "Object ".$_[3]." is not instance of RDF::RDFNode"
		unless( (not(defined $_[3])) ||
			($_[3]->isa('RDF::RDFNode')) );

	return new RDF::Statement();
};

sub createUniqueResource {
	return new RDF::Resource();
};

sub createOrdinal {
	croak "Ordinal ".$_[1]." is not an integer"
		unless(int($_[1]));

	return new RDF::Resource();
};

1;
};

__END__

=head1 NAME

RDF::NodeFactory - definiton of the NodeFactory RDF API

=head1 SYNOPSIS

  use RDF::NodeFactory;
  my $factory = new RDF::NodeFactory();
  my $statement = $factory->createStatement(
				$factory->createResource("http://pen.jrc.it/idex.html"),
  				$factory->createResource("author","http://purl.org/schema/1.0#"),
  				$factory->createLiteral("Alberto Reggiori")
				);


=head1 DESCRIPTION

This is just the interface definition. If you are more interested to an example implementation see RDF::Store::NodeFactory(3)

=head1 SEE ALSO

RDF::Store::NodeFactory(3)

=head1 AUTHOR

	Alberto Reggiori <alberto.reggiori@jrc.it>
