# *
# *	Copyright (c) 2000 Alberto Reggiori / <alberto.reggiori@jrc.it>
# *	ISIS/RIT, Joint Research Center Ispra (I)
# *
# * NOTICE
# *
# * This product is distributed under a BSD/ASF like license as described in the 'LICENSE'
# * file you should have received together with this source code. If you did not get a
# * a copy of such a license agreement you can pick up one at:
# *
# *     http://xml.jrc.it/RDFStore/LICENSE
# *
# *
package RDF::Store::RDFNode;
{
use Carp;
use RDF::RDFNode;
use RDF::Digest::Util;

@RDF::Store::RDFNode::ISA = qw ( RDF::RDFNode );

sub new {
	my ($pkg,$label) = @_;
	my $self = $pkg->SUPER::new();

	$self->{_alreadyComputedHashcode} = 0;
	$self->{_hashCode} = 0;
	$self->{label} = $label;
	$self->{algorithm} = "SHA-1";
	
	bless $self,$pkg;
};

sub getLabel {
	return $_[0]->{label};
};

sub toString {
	return $_[0]->{label};
};

sub hashCode {
	if($_[0]->{_alreadyComputedHashcode} == 0) {
		$_[0]->{_hashCode} = RDF::Digest::Util::getHashCode($_[0]->getDigest());
	};
	return $_[0]->{_hashCode}; #this is the key - must check bitwise operations!!!
};

sub getDigest {
	if(not(defined $_[0]->{digest})) {
        	$_[0]->{digest} = RDF::Digest::Util::computeDigest($_[0]->{algorithm},$_[0]->{label})
			or croak "Cannot compute Digest for node ",$_[0]->{label};
    	};
    	return $_[0]->{digest};
};

sub equals {
	my $status;
	if($status = RDF::Digest::Util::equal($_[0]->getDigest()->getDigestBytes(), $_[1]->getDigest()->getDigestBytes())) {
	} else {
		$status= ($_[0]->{label} eq $_[1]->getLabel()) ? 1 : 0;
	};
	return $status;
};

1;
};

__END__

=head1 NAME

RDF::Store::RDFNode - implementation of the RDFNode RDF API

=head1 SYNOPSIS

  use RDF::Store::RDFNode;
  my $node = new RDF::Store::RDFNode();

=head1 DESCRIPTION

An RDF::RDFNode implementation using Digested URIs.

=head1 SEE ALSO

RDF::RDFNode(3) Digest(3)

=head1 AUTHOR

	Alberto Reggiori <alberto.reggiori@jrc.it>
